log_ssl_errors(): Refer to TLS/SSL errors instead of just SSL errors
[privoxy.git] / openssl.c
index 355a7ec..51fcad5 100644 (file)
--- a/openssl.c
+++ b/openssl.c
@@ -1170,11 +1170,11 @@ static void log_ssl_errors(int debuglevel, const char* fmt, ...)
    va_end(args);
    /*
     * In case if called by mistake and there were
* no SSL errors let's report it to the log.
     */
    if (!reported)
    {
-      log_error(debuglevel, "%s: no ssl errors detected", prefix);
+      log_error(debuglevel, "%s: no TLS/SSL errors detected", prefix);
    }
 }
@@ -1170,11 +1170,11 @@ static void log_ssl_errors(int debuglevel, const char* fmt, ...)
    /*
     * In case if called by mistake and there were
-    * no SSL errors let's report it to the log.
+    * no TLS/SSL errors let's report it to the log.
     */
    if (!reported)